@@ -1,7 +1,7 @@
 package App::fiatx;
 
 our $DATE = '2018-06-19'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,11 @@ use Finance::Currency::FiatX;
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Fiat currency exchange rate tool',
+};
+
 our %args_db = (
     db_name => {
         schema => 'str*',
@@ -121,7 +126,7 @@ sub all_spot_rates {
 }
 
 1;
-# ABSTRACT: Get all spot (latest) rates from a source
+# ABSTRACT: Fiat currency exchange rate tool
 
 __END__
 
@@ -131,11 +136,11 @@ __END__
 
 =head1 NAME
 
-App::fiatx - Get all spot (latest) rates from a source
+App::fiatx - Fiat currency exchange rate tool
 
 =head1 VERSION
 
-This document describes version 0.004 of App::fiatx (from Perl distribution App-fiatx), released on 2018-06-19.
+This document describes version 0.005 of App::fiatx (from Perl distribution App-fiatx), released on 2018-06-19.
 
 =head1 SYNOPSIS
 
